from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NbehaviorCls:
	"""Nbehavior commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("nbehavior", core, parent)

	def get_di_timer(self) -> float or bool:
		"""SCPI: [CONFigure]:SIGNaling:FGS:NBEHavior:DITimer \n
		Snippet: value: float or bool = driver.configure.signaling.fgs.nbehavior.get_di_timer() \n
		Configures the data inactivity timer for 5G tracking areas. With enabled timer, an RRC connection is released when there
		has been no activity on the connection (no traffic) for the configured time. \n
			:return: timer: (float or boolean) numeric value: enables the timer and sets the timer value ON: enables the timer, using the configured numeric value OFF: disables the timer (no release due to inactivity)
		"""
		response = self._core.io.query_str('CONFigure:SIGNaling:FGS:NBEHavior:DITimer?')
		return Conversions.str_to_float_or_bool(response)

	def set_di_timer(self, timer: float or bool) -> None:
		"""SCPI: [CONFigure]:SIGNaling:FGS:NBEHavior:DITimer \n
		Snippet: driver.configure.signaling.fgs.nbehavior.set_di_timer(timer = 1.0) \n
		Configures the data inactivity timer for 5G tracking areas. With enabled timer, an RRC connection is released when there
		has been no activity on the connection (no traffic) for the configured time. \n
			:param timer: (float or boolean) numeric value: enables the timer and sets the timer value ON: enables the timer, using the configured numeric value OFF: disables the timer (no release due to inactivity)
		"""
		param = Conversions.decimal_or_bool_value_to_str(timer)
		self._core.io.write(f'CONFigure:SIGNaling:FGS:NBEHavior:DITimer {param}')

	def get_krrc(self) -> bool:
		"""SCPI: [CONFigure]:SIGNaling:FGS:NBEHavior:KRRC \n
		Snippet: value: bool = driver.configure.signaling.fgs.nbehavior.get_krrc() \n
		Selects whether the RRC connection is kept after a registration in a 5G tracking area. \n
			:return: enable: No help available
		"""
		response = self._core.io.query_str('CONFigure:SIGNaling:FGS:NBEHavior:KRRC?')
		return Conversions.str_to_bool(response)

	def set_krrc(self, enable: bool) -> None:
		"""SCPI: [CONFigure]:SIGNaling:FGS:NBEHavior:KRRC \n
		Snippet: driver.configure.signaling.fgs.nbehavior.set_krrc(enable = False) \n
		Selects whether the RRC connection is kept after a registration in a 5G tracking area. \n
			:param enable: No help available
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'CONFigure:SIGNaling:FGS:NBEHavior:KRRC {param}')
